@@ -1,5 +1,5 @@
 /*
-    $Id: kcalc.h,v 1.14 1999/01/12 09:20:32 kulow Exp $
+    $Id: kcalc.h,v 1.20 2000/02/14 07:38:33 charles Exp $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -26,36 +26,17 @@
 #ifndef QTCALC_H
 #define QTCALC_H
 
-#include <unistd.h>
-#include <stdlib.h>
-#include <ctype.h>
+class QLabel;
+class QListBox;
+class QTimer;
+class QPushButton;
+class QRadioButton;
+class QWidget;
 
-#include <qlistbox.h>
-#include <qclipbrd.h> 
-#include <qlist.h>
-#include <qaccel.h>
-#include <qtabdlg.h>
-#include <qwidget.h>
-#include <qtimer.h>
-#include <qdialog.h>
-#include <qmsgbox.h>
-#include <qpixmap.h>
-#include <qapp.h>
-#include <qfont.h>
-#include <qlabel.h>
-#include <qbttngrp.h>
-#include <qchkbox.h>
-#include <qframe.h>
-#include <qgrpbox.h>
-#include <qlined.h>
-#include <qpushbt.h>
-#include <qradiobt.h>
-#include <qtooltip.h>
+class ConfigureDialog;
+class DLabel;
 
-#include <kapp.h>
-
-
-#include "dlabel.h"
+#include <kdialog.h>
 #include "stats.h"
 
 
@@ -69,7 +50,7 @@
 #define STACK_SIZE	100
 #define TEMP_STACK_SIZE 1000 // the number of numbers kept in the temp stack 
                              // which are accessible with the up and down arrow
-                             // key
+                            // key
 
 #define PRECEDENCE_INCR	20
 
@@ -197,17 +178,20 @@ typedef struct _DefStruct{
 }DefStruct;
 
 
-class QtCalculator : public QDialog
+class QtCalculator : public KDialog
 {
     Q_OBJECT
 
 public:
 
     QtCalculator( QWidget *parent=0, const char *name=0 );
+    ~QtCalculator( void );
 
-    void QtCalculator::keyPressEvent( QKeyEvent *e );    
-    void QtCalculator::keyReleaseEvent( QKeyEvent *e );
-    void  closeEvent( QCloseEvent *e );
+    void updateGeometry( void );
+
+    void keyPressEvent( QKeyEvent *e );    
+    void keyReleaseEvent( QKeyEvent *e );
+    void closeEvent( QCloseEvent *e );
     void writeSettings();
     void readSettings();
     void set_precision();
@@ -225,6 +209,7 @@ public:
 public slots:
 
     void helpclicked();
+    void configurationChanged( const DefStruct &state ); 
     void set_colors();
     void display_selected();
     void invertColors();
@@ -232,8 +217,9 @@ public slots:
     void selection_timed_out();
     void clear_buttons();
     void clear_status_label();
-    void setStatusLabel(const char*);
+    void setStatusLabel(const QString&);
     void EnterDigit(int data);
+    void SubtractDigit();
     void EnterDecimal();
     void EnterStackFunction(int data);
     void EnterNegate();
@@ -354,12 +340,19 @@ public slots:
     void pbhyptoggled(bool myboolean);
     void configclicked();
 
+
+
 public:
 
      DefStruct kcalcdefaults;
  
 private:
-
+    QWidget *mSmallPage;
+    QWidget *mLargePage;
+    
+    QPushButton *mConfigButton;
+    QPushButton *mHelpButton;
+    
     QTimer* selection_timer;
     QLabel* statusINVLabel;
     QLabel* statusHYPLabel;
@@ -417,17 +410,12 @@ private:
     QPushButton* 	pbmod;    
     
     bool		key_pressed;
-    int 		buttonxmargin;
-    int			myxmargin, myymargin, bigbuttonwidth, smallbuttonwidth;
-    int		        bigbuttonheight, smallbuttonheight;
-    int 		anglegroupheight, anglegroupwidth;
-    int			basegroupheight, basegroupwidth;
-    int			helpbuttonwidth, helpbuttonheight;
-    int			displaywidth, displayheight;
-    int 		radiobuttonwidth, radiobuttonheight;
+    int                 mInternalSpacing;
     KStats		stats;
     QListBox            *paper;
     QTimer		*status_timer;
+    ConfigureDialog     *mConfigureDialog;
+
 };
 
 #endif  //QTCLAC_H
