@@ -1,5 +1,5 @@
-/*
-    $Id: kcalc_core.cpp,v 1.21.2.1 1999/02/23 12:11:08 kulow Exp $
+;/*
+    $Id: kcalc_core.cpp,v 1.29 2000/04/30 06:34:07 waba Exp $
 
     kCalculator, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -29,21 +29,26 @@
 */
 
 
-#include <stdio.h>
 #include <errno.h>
 #include <limits.h>
 #include <math.h>
 #include <signal.h>
+#include <stdio.h>
+#include <stdlib.h>
+
 #include <kapp.h>
 #include <klocale.h>
+#include <kmessagebox.h>
+
+#include "dlabel.h"
 #include "kcalc.h"
 
 // Undefine HAVE_LONG_DOUBLE for Beta 4 since RedHat 5.0 comes with a borken
 // glibc
 
-#ifdef HAVE_LONG_DOUBLE
-#undef HAVE_LONG_DOUBLE
-#endif
+//#ifdef HAVE_LONG_DOUBLE
+//#undef HAVE_LONG_DOUBLE
+//#endif
 
 #ifndef HAVE_FUNC_ISINF
 #ifdef HAVE_IEEEFP_H
@@ -248,6 +253,28 @@ void QtCalculator::EnterDigit(int data)
   UpdateDisplay();
 }
 
+void QtCalculator::SubtractDigit()
+{
+// This function could be better, possibly, but am I glad to see it!
+  
+  if (DISPLAY_AMOUNT!=0)
+  {
+    QString num;
+    num.setNum((double)DISPLAY_AMOUNT,'G',24);
+
+    num=num.left(num.length()-1);
+    
+    DISPLAY_AMOUNT= strtod((const char*)num ,0);
+
+  }
+
+#ifdef MYDEBUG
+    printf("SubtractDigit()");
+#endif
+
+  UpdateDisplay();
+}
+
 void QtCalculator::button0()
 {
   EnterDigit(0);
@@ -632,7 +659,7 @@ void QtCalculator::EnterFactorial()
 	while (work_amount1 != 0 && work_amount2 != 0 && !display_error) {
 		work_amount1 *= work_amount2;
 		work_amount2 -= incr;
-		if(isinf(work_amount1)) {
+		if(ISINF(work_amount1)) {
 		  display_error=1;
 		   break;
 		}
@@ -714,10 +741,10 @@ void QtCalculator::EnterHyp()
     hyp_mode = !hyp_mode;
   
     if (hyp_mode){
-      statusHYPLabel->setText("HYP");
+      statusHYPLabel->setText(QString::fromLatin1("HYP"));
     }
     else{
-      statusHYPLabel->setText("");
+      statusHYPLabel->clear();
     }
     break;
   }
@@ -1307,8 +1334,12 @@ void QtCalculator::EE()
   if(inverse){
     DISPLAY_AMOUNT = pi;
     inverse = FALSE;
+    refresh_display = 1;
     UpdateDisplay();
   }
+  else if (refresh_display){
+    //TODO: toggle between exponential and normal display
+  }
   else{
     if(eestate == true)
       eestate = false;
@@ -1547,7 +1578,7 @@ void QtCalculator::UpdateDisplay()
 
 	if (display_error || str_size < 0) { 
 	  display_error = 1;
-	  strcpy(display_str,"Error");
+	  strcpy(display_str, i18n("Error"));
 	  if(kcalcdefaults.beep)
 	    QApplication::beep();
 	}
@@ -1565,7 +1596,7 @@ void QtCalculator::UpdateDisplay()
     statusHYPLabel->setText("HYP");
   }
   else{
-    statusHYPLabel->setText("");
+    statusHYPLabel->clear();
   }
 
 
@@ -1628,26 +1659,21 @@ int UpdateStack(int run_precedence)
 		return_value = 1;
 
 		if ((top_item = PopStack())->s_item_type != ITEM_AMOUNT){
-		  QMessageBox::message( i18n("Error"), 
-					i18n("Stack processing error - right_op"), i18n("OK") );
+		  KMessageBox::error(0L, i18n("Stack processing error - right_op"));
 
 		}
 		right_op = top_item->s_item_data.item_amount;
 
 		if (!((top_item = PopStack()) && 
-		top_item->s_item_type == ITEM_FUNCTION)) {
-		  QMessageBox::message( i18n("Error"), 
-					i18n("Stack processing error - function"), i18n("OK") );
+		top_item->s_item_type == ITEM_FUNCTION))
+		  KMessageBox::error(0L, i18n("Stack processing error - function") );
 
-		}
 		op_function = 
 			top_item->s_item_data.item_func_data.item_function;	
 
-		if (!((top_item = PopStack()) && 
-		top_item->s_item_type == ITEM_AMOUNT)) {
-		  QMessageBox::message( i18n("Error"), 
-					i18n("Stack processing error - left_op"), i18n("OK") );
-		}
+		if (!((top_item = PopStack()) && top_item->s_item_type == ITEM_AMOUNT))
+		  KMessageBox::error(0L, i18n("Stack processing error - left_op") );
+
 		left_op = top_item->s_item_data.item_amount;
 	
 		new_item.s_item_data.item_amount = 
@@ -1950,17 +1976,13 @@ stack_ptr AllocStackItem (void) {
 		return &process_stack[stack_next++];
 	}
 
-	QMessageBox::message( i18n("Emergency"), i18n("Stack Error!"), i18n("OK") );
+	KMessageBox::error(0L, i18n("Stack Error!") );
 	return &process_stack[stack_next];
 }
 
 void UnAllocStackItem (stack_ptr return_item) {
-
-	if (return_item != &process_stack[--stack_next]) {
-	
-	  QMessageBox::message( i18n("Emergency"), i18n("Stack Error!"), i18n("OK") );
-	}	
-
+	if (return_item != &process_stack[--stack_next])
+	  KMessageBox::error(0L, i18n("Stack Error!") );
 }
 void PushStack(item_contents *add_item) 
 {
@@ -2056,5 +2078,3 @@ void InitStack (void) {
 	stack_last = STACK_SIZE - 1;
 	top_of_stack = top_type_stack[0] = top_type_stack[1] = NULL;
 }
-
-	
