@@ -1,7 +1,7 @@
 
 /*
 
-    $Id: floppy.cpp,v 1.7.2.3 1999/07/05 00:42:44 porten Exp $
+    $Id: floppy.cpp,v 1.20 2000/04/30 06:53:05 waba Exp $
 
     Copyright (C) 1997 Bernd Johannes Wuebben   
                        wuebben@math.cornell.edu
@@ -25,7 +25,10 @@
 #include "floppy.h"
 #include "floppy.moc"
 
-extern KApplication *mykapp;
+#include <kconfig.h>
+#include <kglobal.h>
+#include <kstddirs.h>
+#include <kmessagebox.h>
 
 extern "C" {
 int  check_if_mounted(const char *file, int *mount_flags);
@@ -146,7 +149,7 @@ FloppyData::FloppyData
 	lineedit = new QLineEdit( this, "Lineedit" );
 	lineedit->setGeometry( 35, 225, 170, 25 );
 	lineedit->setText(i18n( "KDE Floppy") );
-	lineedit->setMaxLength(10);
+	lineedit->setMaxLength(11);
 
 
 
@@ -218,13 +221,13 @@ bool FloppyData::findDevice()
 {
 
 
-  if((QString) deviceComboBox->currentText() == (QString) FLOPPYA3){
-    if((QString) densityComboBox->currentText() == (QString)i18n( "HD")){
+  if( deviceComboBox->currentText() == FLOPPYA3 ){
+    if( densityComboBox->currentText() == i18n( "HD")){
       device = "/dev/fd0H1440";
       blocks = 1440;
       tracks = 80;
       mdev = "/dev/fd0";
-      if(access(device.data(),W_OK) < 0){
+      if( access(device.data(),W_OK) < 0){
 	device = "/dev/fd0u1440";
       }
     }
@@ -233,14 +236,14 @@ bool FloppyData::findDevice()
       blocks = 720;
       tracks = 80;
       mdev = "/dev/fd0";
-      if(access(device.data(),W_OK) < 0){
+      if( access(device.data(),W_OK) < 0){
 	device = "/dev/fd0u720";
       }
     }
   }
 
-  if((QString) deviceComboBox->currentText() == (QString) FLOPPYA5){
-    if((QString) densityComboBox->currentText() == (QString)i18n( "HD")){
+  if( deviceComboBox->currentText() == FLOPPYA5){
+    if( densityComboBox->currentText() == i18n( "HD")){
       device = "/dev/fd0h1200";
       blocks = 1200;
       tracks = 80;
@@ -254,8 +257,8 @@ bool FloppyData::findDevice()
     }
   }
 
-  if((QString) deviceComboBox->currentText() == (QString) FLOPPYB3){
-    if((QString) densityComboBox->currentText() == (QString)i18n( "HD")){
+  if( deviceComboBox->currentText() == FLOPPYB3){
+    if( densityComboBox->currentText() == i18n( "HD")){
       device = "/dev/fd1H1440";
       blocks = 1400;
       tracks = 80;
@@ -269,14 +272,14 @@ bool FloppyData::findDevice()
       blocks = 720;
       tracks = 80;
       mdev = "/dev/fd1";
-      if(access(device.data(),W_OK) < 0){
+      if( access(device.data(),W_OK) < 0){
 	device = "/dev/fd1u720";
-      }
+    }
     }
   }
 
-  if((QString) deviceComboBox->currentText() == (QString) FLOPPYB5){
-    if((QString) densityComboBox->currentText() == (QString)i18n( "HD")){
+  if( deviceComboBox->currentText() == FLOPPYB5){
+    if( densityComboBox->currentText() == i18n( "HD")){
       device = "/dev/fd1h1200";
       blocks = 1200;
       tracks = 80;
@@ -293,13 +296,10 @@ bool FloppyData::findDevice()
 
   if( access(device.data(),W_OK) < 0){
 
-    QString str;
-    str.sprintf(i18n(
-	      "Cannot access %s\nMake sure that the device exists and that\n"
-	      "you have write permission to it."),device.data());
-    QMessageBox::critical(this,
-		      i18n( "KFloppy"),
-		       str.data());
+    QString str = i18n(
+	      "Cannot access %1\nMake sure that the device exists and that\n"
+	      "you have write permission to it.").arg(device);
+    KMessageBox::error(this, str);
 
     formatbutton->setEnabled(FALSE);
     return false;
@@ -317,36 +317,22 @@ bool FloppyData::findExecutables(){
   bool mke2fs   = false;
   bool ok 	= true;
   
-  QFileInfo info;
-  QString directory;
- 
-  directory = mykapp->kde_bindir();
-
-  info.setFile(directory + "/kfdformat");
-  if (info.isExecutable()){
+  if (KGlobal::dirs()->findExe("kfdformat").length()) {
     mkformat = true;
   }
-
-  info.setFile(directory + "/kmke2fs");
-  if (info.isExecutable()){
+  if (KGlobal::dirs()->findExe("kmke2fs").length()) {
     mke2fs = true;
   }
-
-  info.setFile(directory + "/kmkdosfs");
-  if (info.isExecutable()){
+  if (KGlobal::dirs()->findExe("kmkdosfs").length()) {
     mkdosfs = true;
   }
 
   if(!mkformat){
 
-    QString str;
-    str.sprintf(
-		i18n(
+    QString str = i18n(
        	"Cannot find kfdformat\nkfdformat is part of the KFloppy distribution.\n"
-	"Please install KFloppy properly."));
-    QMessageBox::critical(this,
-			  i18n("KFloppy"),
-		       str.data());
+	"Please install KFloppy properly.");
+    KMessageBox::error(this, str);
 
     formatbutton->setEnabled(FALSE);
     ok = false;
@@ -354,15 +340,10 @@ bool FloppyData::findExecutables(){
   }
 
   if( !mke2fs){
-
-    QString str;
-    str.sprintf(
-		i18n(
+    QString str = i18n(
           "Cannot find kmke2fs\nkmke2fs is part of the KFloppy distribution.\n"
-	  "Please install KFloppy properly."));
-    QMessageBox::critical(this,
-		       i18n("KFloppy"),
-		       str.data());
+	  "Please install KFloppy properly.");
+    KMessageBox::error(this, str);
 
     formatbutton->setEnabled(FALSE);
     ok = false;
@@ -370,15 +351,10 @@ bool FloppyData::findExecutables(){
 
   if( !mkdosfs){
 
-    QString str;
-    str.sprintf(
-		i18n(
+    QString str = i18n(
 		"Cannot find kmkdosfs\nkmkdosfs is part of the KFloppy distribution.\n"
-		"Please install KFloppy properly.")
-		);
-    QMessageBox::critical(this,
-		       i18n("KFloppy"),
-		       str.data());
+		"Please install KFloppy properly.");
+    KMessageBox::error(this, str);
 
     formatbutton->setEnabled(FALSE);
     ok = false;
@@ -398,10 +374,7 @@ void FloppyData::quit(){
     
   }
   writeSettings();
-  mykapp->quit();
-
-
-
+  kapp->quit();
 }
 
 void FloppyData::reset(){
@@ -416,7 +389,7 @@ void FloppyData::reset(){
   }
   proc = 0L;
   progress->setValue(0);
-  frame->setText("");
+  frame->clear();
   formatbutton->setText(i18n("Format"));
 
 }
@@ -478,21 +451,12 @@ void FloppyData::format(){
   bool result = proc->start(KProcess::NotifyOnExit , KProcess::All);
 
   if(!result){
-    QString str;
-    str.sprintf(
-		i18n(
-		"Cannot start a new program: fork() failed."
-		));
-    QMessageBox::critical(this,
-		       i18n("KFloppy"),
-		       str.data());
+    QString str = i18n("Cannot start a new program: fork() failed.");
+    KMessageBox::error(this, str);
     reset();
   }
-
-
 }
 
-
 void FloppyData::formatdone(KProcess*){
 
   if(proc){
@@ -534,7 +498,7 @@ void FloppyData::readStdout(KProcess *, char *buffer, int buflen){
     else
       newstring = formatstring;
 
-    frame->setText(newstring.data());
+    frame->setText(newstring);
     increment =false;
   }
 
@@ -578,38 +542,26 @@ void FloppyData::errslot(){
 
   if(errstring.contains("ioctl(FDFMTBEG)")){
 
-    QString str;
-    str.sprintf(
-		i18n(
-		"Cannot access floppy or floppy drive\n"\
+    QString str = i18n(
+		"Cannot access floppy or floppy drive\n"
 		"Please insert a floppy and make sure that you\n"
-		"have selected a valid floppy drive.\n")
-		);
+		"have selected a valid floppy drive.\n");
 
-    QMessageBox::warning(this,
-		       i18n("KFloppy"),
-		       str.data());
+    KMessageBox::error(this, str);
     
     reset();
     return;
 
   }
 
-  QString str;
-  str.sprintf(i18n("Cannot format: "\
-	      "%s\n"\
-	      "%s"),device.data(),errstring.data());
-
-  QMessageBox::warning(this,
-		   i18n(    "KFloppy"),
-		       str.data());
+  QString str = i18n("Cannot format: %1\n%2").arg(device).arg(errstring);
 
+  KMessageBox::error(this, str);
 
   reset();
-
 }
-void FloppyData::readfsStdout(KProcess *, char *buffer, int buflen){
 
+void FloppyData::readfsStdout(KProcess *, char *buffer, int buflen){
   char mybuffer[1001];
   int amount;
 
@@ -627,7 +579,7 @@ void FloppyData::readfsStdout(KProcess *, char *buffer, int buflen){
   
   QString string ;
   QString newstring = fsstring;
-  newstring.detach();
+  
 
   int i;
 
@@ -643,8 +595,8 @@ printf("NEWLINE:%s\n",mystring.data());
     if(findKeyWord(mystring,"BBF ")){
       int bblock = atoi(mystring.left(8).data());
       QString mstr;
-      mstr.sprintf(i18n("Block %d is bad. Continuing ..."),bblock);
-      frame->setText(mstr.data());
+      mstr = i18n("Block %1 is bad. Continuing ...").arg(bblock);
+      frame->setText(mstr);
     }
 
     if(findKeyWord(mystring,"TNBB ")){
@@ -706,18 +658,12 @@ void FloppyData::fserrslot(){
 
   if(fserrstring.contains("No such device")){
 
-    QString str;
-    str.sprintf(
-		i18n(
+    QString str = i18n(
 		"Cannot access floppy or floppy drive\n"\
 		"Please insert a floppy and make sure that you\n"
- 		"have selected a valid floppy drive.\n"
-		)
-		);
+ 		"have selected a valid floppy drive.\n");
 
-    QMessageBox::warning(this,
-		       i18n("KFloppy"),
-		       str.data());
+    KMessageBox::sorry(this, str);
     
     reset();
     return;
@@ -725,14 +671,10 @@ void FloppyData::fserrslot(){
 
   reset();
 
-  QString str;
-  str.sprintf(i18n("Cannot create a filesystem on: %s\n%s")
-	      ,device.data(),fserrstring.data());
-
-  QMessageBox::warning(this,
-		       i18n("KFloppy"),
-		       str.data());
+  QString str = i18n("Cannot create a filesystem on: %1\n%2")
+	      .arg(device).arg(fserrstring);
 
+  KMessageBox::error(this, str);
 }
 
 
@@ -758,43 +700,23 @@ void FloppyData::cf2done(){
     return;
 
   if(!lcquick){
-    QString str;
+    QString str = i18n(
+		"The floppy was sucessfully formatted.\n"
+		"Blocks marked bad: %1\n"
+		"Raw Capacity: %2\n")
+		.arg(badblocks)
+		.arg((blocks - badblocks)*1024);
 
-    str.sprintf(
-		i18n(
-		"The floppy was sucessfully formatted.\n"\
-		"Blocks marked bad: %d\n"\
-		"Raw Capacity: %d\n"),
-		badblocks,
-		(blocks - badblocks)*1024
-		);
-
-    /*    str.sprintf("The floppy was sucessfully formatted.\n"\
-		"Raw Capacity: %d\n"
-		"Blocks marked bad: %d\n"\
-		"Free Space: %d",blocks*1024,badblocks,
-		(blocks - badblocks) * 1024);
-		*/
-
-    QMessageBox::information(this,
-			     i18n("KFloppy"),
-			     str.data());
+    KMessageBox::information(this, str);
   }
   else{
+    QString str = i18n("All files were sucessfully erased.");
 
-    QString str;
-    str.sprintf(i18n("All files were sucessfully erased."));
-
-    QMessageBox::information(this,
-			     i18n("KFloppy"),
-			     str.data());
-
+    KMessageBox::information(this, str);
   }
-
 }
 
-
-int FloppyData::findKeyWord(QString& string,char* word){
+int FloppyData::findKeyWord(QString& string,const char* word){
 
   int count = 0;
   int index = 0;
@@ -887,15 +809,9 @@ void FloppyData::createfilesystem(){
   bool result = proc->start(KProcess::NotifyOnExit , KProcess::All);
 
   if(!result){
-    QString str;
-    str.sprintf(
-		i18n(
-		"Cannot start a new program\nfork() failed.")
-		);
-    QMessageBox::critical(this,
-		       i18n("KFloppy"),
-		       str.data());
-    frame->setText("");
+    QString str = i18n("Cannot start a new program\nfork() failed.");
+    KMessageBox::error(this, str);
+    frame->clear();
     proc = 0L;
     progress->setValue(0);
   }
@@ -913,8 +829,7 @@ bool FloppyData::checkmount(){
 
   retval = check_if_mounted(mdev.data(), &mount_flags);
   if (retval) {
-    QMessageBox::warning(this,
-		      i18n("KFloppy"),
+    KMessageBox::error(this,
 		      i18n(
 		      "Error while trying to determine whether floppy is mounted\n"
 		      )
@@ -930,25 +845,13 @@ bool FloppyData::checkmount(){
 
 
 
-  QString str;
-  str.sprintf(
-	      i18n(
-	      "%s is mounted.\nPlease unmount the floppy first."
-	      )
-	      ,mdev.data());
-
-  QMessageBox::warning(this,
-		       i18n("KFloppy"),
-		       str.data());  
-
-
- return false;
+  QString str = i18n("%1 is mounted.\nPlease unmount the floppy first.")
+	        .arg(mdev);
+  KMessageBox::error(this, str);  
 
+  return false;
 }
 
-
-
-
 void FloppyData::about(){
 
   QDialog *dlg = new MyAbout(0);
@@ -969,16 +872,13 @@ void FloppyData::about(){
 
 
 void FloppyData::help(){
-
-  mykapp->invokeHTMLHelp("kfloppy/kfloppy.html","");
-
-
+  kapp->invokeHTMLHelp("kfloppy/kfloppy.html","");
 }
 
 
 void FloppyData::writeSettings(){
 
-        config = mykapp->getConfig();
+        config = kapp->config();
 	config->setGroup("GeneralData");
 
 	densityconfig = densityComboBox->currentText();
@@ -999,27 +899,27 @@ void FloppyData::writeSettings(){
 	labelconfig = labellabel->isChecked();
 
 	config->writeEntry("CreateLabel",labelconfig);
-	config->writeEntry("Label",labelnameconfig.data());
+	config->writeEntry("Label",labelnameconfig);
 
 
 	config->writeEntry("QuickFormat",quickformatconfig);
-	config->writeEntry("FLoppyDrive",driveconfig.data());
-	config->writeEntry("Density",densityconfig.data());
-	config->writeEntry("Filesystem",filesystemconfig.data());
+	config->writeEntry("FloppyDrive",driveconfig);
+	config->writeEntry("Density",densityconfig);
+	config->writeEntry("Filesystem",filesystemconfig);
 	config->sync();
 
 }
 
 void FloppyData::readSettings(){
 
-        config = mykapp->getConfig();
+        config = kapp->config();
 	config->setGroup("GeneralData");
 
 	labelconfig = config->readNumEntry("CreateLabel",1);
 	labelnameconfig = config->readEntry("Label","KDE Floppy");
 	quickformatconfig = config->readNumEntry("QuickFormat",0);
-	driveconfig = config->readEntry("FLoppyDrive",FLOPPYA3);
-	densityconfig = config->readEntry("Density",i18n("HD"));
+	driveconfig = config->readEntry("FloppyDrive","A: 3.5");
+	densityconfig = config->readEntry("Density","HD");
 	filesystemconfig = config->readEntry("Filesystem","Dos");
 
 }
@@ -1042,7 +942,7 @@ void FloppyData::setWidgets(){
     quick->setChecked(FALSE);
     fullformat->setChecked(TRUE);
   }
-  lineedit->setText(labelnameconfig.data());
+  lineedit->setText(labelnameconfig);
 
   for(int i = 0 ; i < deviceComboBox->count(); i++){
     if ( (QString) deviceComboBox->text(i) == driveconfig){
