@@ -1,10 +1,11 @@
 
 #include "ConfAutoUpdateData.h"
 
-#include <qlcdnum.h>
+#include <qlcdnumber.h>
 #include <qlabel.h>
 
 #include <kapp.h>
+#include <klocale.h>
 
 ConfAutoUpdateData::ConfAutoUpdateData
 (
@@ -14,7 +15,7 @@ ConfAutoUpdateData::ConfAutoUpdateData
 	QLabel* tmpQLabel;
 	tmpQLabel = new QLabel( parent, "Label_1" );
 	tmpQLabel->setGeometry( 16, 24, 180, 24 );
-	tmpQLabel->setText( klocale->translate("Update frequency in seconds:") );
+	tmpQLabel->setText( i18n("Update frequency in seconds:") );
 
 	s_freq = new QScrollBar( parent, "ScrollBar_1" );
 	s_freq->setGeometry( 24, 48, 160, 16 );
@@ -29,11 +30,11 @@ ConfAutoUpdateData::ConfAutoUpdateData
 
 	b_ok = new QPushButton( parent, "PushButton_1" );
 	b_ok->setGeometry( 32, 120, 80, 24 );
-	b_ok->setText( klocale->translate("OK") );
+	b_ok->setText( i18n("OK") );
 
 	b_cancel = new QPushButton( parent, "PushButton_2" );
 	b_cancel->setGeometry( 176, 120, 80, 24 );
-	b_cancel->setText( klocale->translate("Cancel") );
+	b_cancel->setText( i18n("Cancel") );
 
 	parent->resize( 288, 168 );
 }
