@@ -1,9 +1,9 @@
 #ifndef ConfAutoUpdateData_included
 #define ConfAutoUpdateData_included
 
-//#include <qlcdnum.h>
-#include <qpushbt.h>
-#include <qscrbar.h>
+//#include <qlcdnumber.h>
+#include <qpushbutton.h>
+#include <qscrollbar.h>
 
 class QLCDNumber;
 
