@@ -25,197 +25,134 @@ extern "C" {
 #include <unistd.h>
 };
 
-#include <qchkbox.h>
-#include <qcombo.h>
+#include <qcheckbox.h>
+#include <qcombobox.h>
 #include <qframe.h>
+#include <qgroupbox.h>
 #include <qlabel.h>
 #include <qlistbox.h>
-#include <qmenubar.h>
-#include <qpushbt.h>
+#include <qlistview.h>
+#include <qpushbutton.h>
 #include <qkeycode.h>
-#include <qmsgbox.h>
-#include <qobjcoll.h>
-#include <qfileinf.h>
+#include <qcollection.h>
+#include <qfileinfo.h>
 #include <qdir.h>
 #include <qcursor.h>
+#include <qevent.h>
+#include <qdragobject.h>
 
 #include <kprocess.h>
-#include <kmsgbox.h>
-#include <kfm.h>
-#include <drag.h>
+#include <kmessagebox.h>
+#include <klocale.h>
+#include <kconfig.h>
+#include <kmenubar.h>
+#include <kstdaccel.h>
+
 #include "klpq.h"
 #include "klpq.moc"
 #include "queueview.h"
-#include "kheader.h"
 #include "klpqspooler.h"
 #include "FirstStart.h"
 
-Klpq::Klpq(const char* name=0) 
-  : KTopLevelWidget( name )
+Klpq::Klpq( const char *name )
+  : KTMainWindow( name )
 {
-  initMetaObject();
-
-  update_delay = 0;                             // means no auto update at all
-  kfm = 0;
-  setCaption(KApplication::getKApplication()->getCaption());
-  KConfig *config = KApplication::getKApplication()->getConfig();
+  update_delay = 0; // means no auto update at all
+  KConfig *config = KApplication::kApplication()->config();
   config->setGroup("klpq");
   if( config->hasKey("updateDelay") )
     update_delay = config->readNumEntry("updateDelay");
 
-  conf_auto = new ConfAutoUpdate();
-  conf_auto->setFreq(update_delay);
+  conf_auto = new ConfAutoUpdate( topLevelWidget(), "update" );
+  conf_auto->setFrequency(update_delay);
 
-  conf_spooler = new SpoolerConfig();
+  conf_spooler = new SpoolerConfig( topLevelWidget(), "spooler" );
 
-  menubar = new KMenuBar( this, "MenuBar_1" );
-  menubar->setGeometry( 0, 0, 620, 28 );
-  menubar->setFrameStyle( 34 );
-  menubar->setLineWidth( 2 );
-  
   f_main = new QFrame( this, "Frame_1" );
-  f_main->move( 0, 28 );
-//  f_main->setMinimumSize( 520, 370 );
-  
-  f_top = new QFrame( f_main, "Frame_2" );
-//  f_top->setMinimumSize( 520, 28 );
-  f_top->setFrameStyle( 49 );
-  
-  cb_printer = new QComboBox( f_top, "ComboBox_1" );
-//  cb_printer->setFixedSize( 120, 20 );
-  cb_printer->setFixedSize( cb_printer->sizeHint() );
+
+  f_top = new QGroupBox(i18n("Printer Configuration"), f_main, "Frame_2" );
+
+  QVBoxLayout *vlayout = new QVBoxLayout(f_top, KDialog::marginHint(),
+					 KDialog::spacingHint());
+  vlayout->addSpacing(f_top->fontMetrics().lineSpacing());
+
+  QHBoxLayout *hlayout = new QHBoxLayout;
+  vlayout->addLayout(hlayout);
 
   l_printer = new QLabel( f_top, "Label_1" );
-//  l_printer->setFixedSize( 48, 20 );
-  l_printer->setText( klocale->translate("Printer") );
-  l_printer->setFixedSize( l_printer->sizeHint() );
+  l_printer->setText( i18n("Printer name:") );
+  hlayout->addWidget( l_printer, 0 );
+
+  cb_printer = new QComboBox( f_top, "ComboBox_1" );
+  hlayout->addWidget( cb_printer, 3, AlignLeft );
 
   c_queuing = new QCheckBox( f_top, "CheckBox_1" );
-//  c_queuing->setFixedSize( 72, 20 );
-  c_queuing->setText( klocale->translate("Queuing") );
-  c_queuing->setFixedSize( c_queuing->sizeHint() );
+  c_queuing->setText( i18n("Queuing") );
+  hlayout->addWidget( c_queuing, 1 );
 
   c_printing = new QCheckBox( f_top, "CheckBox_2" );
-//  c_printing->setFixedSize( 72, 20 );
-  c_printing->setText( klocale->translate("Printing") );
-  c_printing->setFixedSize( c_printing->sizeHint() );
+  c_printing->setText( i18n("Printing") );
+  hlayout->addWidget( c_printing, 1 );
 
-  b_update = new QPushButton( f_top, "PushButton_1" );
-//  b_update->setFixedSize( 84, 20 );
-  b_update->setText( klocale->translate("Update") );
-  b_update->setFixedSize( b_update->sizeHint() );  
+  lb_list = new QListView(f_main);
+  lb_list->addColumn(i18n("Rank"), 75);
+  lb_list->addColumn(i18n("Owner"), 150);
+  lb_list->addColumn(i18n("Job"), 75);
+  lb_list->addColumn(i18n("Files"), 150);
+  lb_list->addColumn(i18n("Size"), 75);
 
-  b_quit = new QPushButton( f_top, "PushButton_2" );
-//  b_quit->setFixedSize( 56, 20 );
-  b_quit->setText( klocale->translate("Quit") );
-  b_quit->setFixedSize( b_quit->sizeHint() );
-  
-  f_list = new QFrame( f_main, "Frame_3" );
-//  f_list->setMinimumSize( 520, 84 );
-  f_list->setFrameStyle( 50 );
-  
-  lb_list = new MyRowTable( f_list, "ListBox_1" );
-  lb_list->setMinimumSize( 504, 60 );
-  lb_list->setFrameStyle( 51 );
-  lb_list->setLineWidth( 2 );
-  lb_list->setAutoDelete(TRUE);
+  //  connect( lb_list, SIGNAL(rightButtonClicked()), this, SLOT(popupMenu()) );
 
-  h_list = new KHeader( f_list, "Header_1", 5, KHeader::Resizable | KHeader::Buttons );
-  h_list->setMinimumSize( 504, 20 );  
-  h_list->setHeaderLabel( 0, klocale->translate("Rank"), AlignLeft | AlignVCenter );
-  h_list->setHeaderLabel( 1, klocale->translate("Owner"), AlignLeft | AlignVCenter );
-  h_list->setHeaderLabel( 2, klocale->translate("Job"), AlignLeft | AlignVCenter );
-  h_list->setHeaderLabel( 3, klocale->translate("Files"), AlignLeft | AlignVCenter );
-  h_list->setHeaderLabel( 4, klocale->translate("Size"), AlignLeft | AlignVCenter );
+  top2bottom = new QVBoxLayout( f_main, KDialog::marginHint(),
+				KDialog::spacingHint());
+  top2bottom->addWidget( f_top );
+  top2bottom->addWidget( lb_list, 1 );
 
-  connect( h_list, SIGNAL(sizeChanged(int,int)),
-	   lb_list, SLOT(setColumnWidth(int,int)) );
-  // This connection makes it jumpy and slow (but it works!)
-  //      connect( h_list, SIGNAL(sizeChanging(int,int)),
-  //                       lb_list, SLOT(setColumnWidth(int,int)) );
-  connect( lb_list, SIGNAL(hSliderMoved(int)),
-	   h_list, SLOT(setOrigin(int)) );
-  connect( lb_list, SIGNAL(rightButtonClicked()), this, SLOT(popupMenu()) );
+  hlayout = new QHBoxLayout;
+  top2bottom->addLayout(hlayout);
 
-  f_bottom = new QFrame( f_main, "f_bottom" );
-  f_bottom->setMinimumSize( 100, 52 );
+  vlayout = new QVBoxLayout;
+  hlayout->addLayout(vlayout);
 
-  b_remove = new QPushButton( f_bottom, "PushButton_3" );
-//  b_remove->setFixedSize( 64, 24 );
-  b_remove->setText( klocale->translate("Remove") );
-  b_remove->setFixedSize( b_remove->sizeHint() );
+  b_remove = new QPushButton( f_main, "PushButton_3" );
+  b_remove->setText( i18n("Remove") );
+  vlayout->addWidget(b_remove);
 
-  b_make_top = new QPushButton( f_bottom, "PushButton_4" );
-//  b_make_top->setFixedSize( 64, 24 );
-  b_make_top->setText( klocale->translate("Make Top") );
-  b_make_top->setFixedSize( b_make_top->sizeHint() );
-  
-  lb_status = new QListBox( f_bottom, "ListBox_2" );
+  b_make_top = new QPushButton( f_main, "PushButton_4" );
+  b_make_top->setText( i18n("Make Top") );
+  vlayout->addWidget(b_make_top);
+
+  lb_status = new QListBox( f_main, "ListBox_2" );
   lb_status->setMinimumSize( 312, 44 );
-  lb_status->setFrameStyle( 51 );
-  lb_status->setLineWidth( 2 );
-  
-  b_auto = new QPushButton( f_bottom, "PushButton_6" );
-//  b_auto->setFixedSize( 48, 24 );
-  b_auto->setText( klocale->translate("Auto") );
+  hlayout->addWidget(lb_status);
+
+  vlayout = new QVBoxLayout;
+  hlayout->addLayout(vlayout);
+
+  b_auto = new QPushButton( f_main, "PushButton_6" );
+  b_auto->setText( i18n("Auto") );
   b_auto->setToggleButton( TRUE );
-  b_auto->setFixedSize( b_auto->sizeHint() );
-  
-  top2bottom = new QGridLayout( f_main, 3, 1, 4 );
-  top2bottom->addWidget( f_top, 0, 0, AlignCenter );
-  top2bottom->addWidget( f_list, 1, 0, AlignCenter );
-  top2bottom->setRowStretch( 1, 1 );
-  top2bottom->addWidget( f_bottom, 2, 0, AlignCenter );
-  top2bottom->activate();
+  vlayout->addWidget(b_auto);
 
-  top_layout = new QBoxLayout( f_top, QBoxLayout::LeftToRight, 4 );
-  top_layout->addSpacing(2);
-  top_layout->addWidget( l_printer );
-  top_layout->addWidget( cb_printer );
-  top_layout->addSpacing(10);
-  top_layout->addWidget( c_queuing );
-  top_layout->addSpacing(6);
-  top_layout->addWidget( c_printing );
-  top_layout->addSpacing(6);
-  top_layout->addWidget( b_update );
-  top_layout->addStretch(5);
-  top_layout->addWidget( b_quit );
-  top_layout->addSpacing(2);
-  top_layout->activate();
-
-  list_layout = new QGridLayout( f_list, 2, 1, 4 );
-  list_layout->addWidget( h_list, 0, 0, AlignCenter );
-  list_layout->addWidget( lb_list, 1, 0, AlignCenter );
-  list_layout->setRowStretch( 1, 1 );
-  list_layout->activate();
-
-  bottom_layout = new QGridLayout( f_bottom, 1, 4, 4 );
-  bottom_layout->addWidget( b_remove, 0, 0, AlignCenter );
-  bottom_layout->addWidget( b_make_top, 0, 1, AlignCenter );
-  bottom_layout->addWidget( lb_status, 0, 2, AlignCenter );
-  bottom_layout->setColStretch( 2, 1 );
-  bottom_layout->addWidget( b_auto, 0, 3, AlignCenter );
-  bottom_layout->activate();
+  b_update = new QPushButton( f_main, "PushButton_1" );
+  b_update->setText( i18n("Update") );
+  vlayout->addWidget( b_update );
 
   QPopupMenu *file = new QPopupMenu;
-  file->insertItem(klocale->translate("&Quit"), qApp, SLOT(quit()));
+  file->insertItem(i18n("&Quit"), qApp, SLOT(quit()), KStdAccel::key(KStdAccel::Quit) );
 
   QPopupMenu *conf_menu = new QPopupMenu;
-  conf_menu->insertItem(klocale->translate("&Auto update"), this, SLOT(configureAuto()) );
-  conf_menu->insertItem(klocale->translate("&Spooler"), this, SLOT(configureSpooler()) );
+  conf_menu->insertItem(i18n("&Update frequency"),this,SLOT(configureAuto()));
+  conf_menu->insertItem(i18n("&Spooler"), this, SLOT(configureSpooler()) );
 
-  QString about;
-  about.sprintf(i18n("Klpq %s\n(C) by Christoph Neerfeld\nchris@kde.org"),
-		KLPQ_VERSION);
-  QPopupMenu *help = KApplication::getKApplication()->getHelpMenu(FALSE, about );
+  QString about = i18n(""
+    "Klpq %1\n(C) by Christoph Neerfeld\nchris@kde.org").arg(KLPQ_VERSION);
+  menuBar()->insertItem( i18n("&File"), file );
+  menuBar()->insertItem( i18n("&Options"), conf_menu );
+  menuBar()->insertSeparator();
+  menuBar()->insertItem( i18n("&Help"), helpMenu( about ) );
 
-  menubar->insertItem( klocale->translate("&File"), file );
-  menubar->insertItem( klocale->translate("&Config"), conf_menu, ALT+Key_C );
-  menubar->insertSeparator();
-  menubar->insertItem( klocale->translate("&Help"), help, ALT+Key_H );  
-
-  connect( b_quit, SIGNAL(clicked()), qApp, SLOT(quit()) );
-  connect( cb_printer, SIGNAL(activated(int)), this, SLOT(printerSelect(int)) );
+  connect( cb_printer, SIGNAL(activated(int)), this, SLOT(printerSelect(int)));
   connect( c_queuing, SIGNAL(clicked()), this, SLOT(queuing()) );
   connect( c_printing, SIGNAL(clicked()), this, SLOT(printing()) );
   connect( b_update, SIGNAL(clicked()), this, SLOT(update()) );
@@ -224,8 +161,8 @@ Klpq::Klpq(const char* name=0)
   connect( b_auto, SIGNAL(clicked()), this, SLOT(setAuto()) );
 
   popup_menu = new QPopupMenu;
-  popup_menu->insertItem( klocale->translate("Remove"), this, SLOT(remove()) );
-  popup_menu->insertItem( klocale->translate("Make Top"), this, SLOT(makeTop()) );
+  popup_menu->insertItem( i18n("Remove"), this, SLOT(remove()) );
+  popup_menu->insertItem( i18n("Make Top"), this, SLOT(makeTop()) );
 
   int key_id;
   accel = new QAccel(this);
@@ -240,9 +177,6 @@ Klpq::Klpq(const char* name=0)
   //accel->connectItem( accel->insertItem( Key_E ), this, SLOT(queuing()) );
   //accel->connectItem( accel->insertItem( Key_I ), this, SLOT(printing()) );
 
-  lb_list->setFocus();
-
-  setMenu(menubar);
   setView(f_main, FALSE);
 
   // set up subprocess
@@ -268,29 +202,20 @@ Klpq::Klpq(const char* name=0)
     }
   lpc = new KProcess;
   lpc_com = NotRunning;
-  connect( lpc, SIGNAL(receivedStdout(KProcess *, char *, int)), 
+  connect( lpc, SIGNAL(receivedStdout(KProcess *, char *, int)),
 	   this, SLOT(recvLpc(KProcess *, char *, int)) );
-  connect( lpc, SIGNAL(processExited(KProcess *)), 
+  connect( lpc, SIGNAL(processExited(KProcess *)),
 	   this, SLOT(exitedLpc(KProcess *)) );
 
   lpq = new KProcess;
   lpq_running = FALSE;
-  connect( lpq, SIGNAL(receivedStdout(KProcess *, char *, int)), 
+  connect( lpq, SIGNAL(receivedStdout(KProcess *, char *, int)),
 	   this, SLOT(recvLpq(KProcess *, char *, int)) );
-  connect( lpq, SIGNAL(processExited(KProcess *)), 
+  connect( lpq, SIGNAL(processExited(KProcess *)),
 	   this, SLOT(exitedLpq(KProcess *)) );
 
-  // add dropZone
-  KDNDDropZone *dropzone = new KDNDDropZone( f_main, DndURL );
-  connect( dropzone, SIGNAL(dropAction(KDNDDropZone *)), this, SLOT(urlDroped(KDNDDropZone *)) );
-
-  // resize window
-//  f_main->resize( 620, 370 );
-//  setMinimumSize(530, 300);
-
-  int max = f_top->width();
-  if (f_bottom->width() > max) max = f_bottom->width();
-  setMinimumSize( max+10, 300 );
+  // activate DnD
+  setAcceptDrops(true);
 
   int width, height;
   config->setGroup("klpq");
@@ -299,39 +224,34 @@ Klpq::Klpq(const char* name=0)
   if( width < minimumSize().width() )
     width = minimumSize().width();
   if( height < minimumSize().height() )
-    height = minimumSize().height(); 
+    height = minimumSize().height();
 
-  h_list->setHeaderSize( 0, config->readNumEntry("rankSize", 40 ) );
-  h_list->setHeaderSize( 1, config->readNumEntry("ownerSize", 100 ) );
-  h_list->setHeaderSize( 2, config->readNumEntry("jobSize", 30 ) );
-  h_list->setHeaderSize( 3, config->readNumEntry("filesSize", 238 ) );
-  h_list->setHeaderSize( 4, config->readNumEntry("sizeSize", 100 ) );
+  resize(f_main->sizeHint());
 
   b_auto->setOn( config->readBoolEntry("autoOn", TRUE) );
   setAuto();
-
-  resize(width, height);
 }
 
 Klpq::~Klpq()
 {
+  delete conf_auto;
+  delete conf_spooler;
+
   delete lpc;
   delete lpq;
-  KConfig *config = KApplication::getKApplication()->getConfig();
-  config->setGroup("klpq");
-  config->writeEntry("Width", width());
-  config->writeEntry("Height", height());
-  config->writeEntry("updateDelay", update_delay);
-  config->writeEntry("rankSize", h_list->getHeaderSize(0) );
-  config->writeEntry("ownerSize", h_list->getHeaderSize(1) );
-  config->writeEntry("jobSize", h_list->getHeaderSize(2) );
-  config->writeEntry("filesSize", h_list->getHeaderSize(3) );
-  config->writeEntry("sizeSize", h_list->getHeaderSize(4) );
-  config->writeEntry("autoOn", b_auto->isOn() );
-  config->writeEntry("lastQueue", cb_printer->currentText() );
-  config->sync();
+
+  KConfig &config = *kapp->config();
+  config.setGroup("klpq");
+  config.writeEntry("Width", width());
+  config.writeEntry("Height", height());
+  config.writeEntry("updateDelay", update_delay);
+  config.writeEntry("autoOn", b_auto->isOn() );
+  config.writeEntry("lastQueue", cb_printer->currentText() );
+  config.sync();
 }
 
+
+
 void Klpq::setLastPrinterCurrent()
 {
   if( cb_printer->count() )
@@ -340,10 +260,9 @@ void Klpq::setLastPrinterCurrent()
 
 void Klpq::update()
 {
-  //debug("lpq = %i / lpc = %i", lpq->isRunning(), lpc->isRunning() );
   if( !isEnabled() )
     return;
-  lpq_in_buffer.resize(0);
+  lpq_in_buffer = QString::null;
   lpq->clearArguments();
 
   spooler->updateCommand( lpq, cb_printer->text( cb_printer->currentItem() ) );
@@ -382,7 +301,7 @@ void Klpq::printing()
       return;
     }
   lpc->clearArguments();
-  spooler->setPrintingCommand( lpc, cb_printer->text( cb_printer->currentItem() ), 
+  spooler->setPrintingCommand( lpc, cb_printer->text( cb_printer->currentItem() ),
 			       c_printing->isChecked() );
   if( lpc->start( KProcess::NotifyOnExit, KProcess::Stdout ) )
     {
@@ -395,18 +314,16 @@ void Klpq::remove()
 {
   if( !isEnabled() )
     return;
-  int i = lb_list->currentItem();
-  if ( i < 0 ) return;
-  int job = lb_list->jobId(i);
+  int job = ((MyLVI *)lb_list->selectedItem())->jobId();
   QString word;
   word.setNum(job);
   QString ask;
-  ask.sprintf( klocale->translate("Do you really want to remove job No %d"), job );
-  if( KMsgBox::yesNo( this, "Klpq", (const char *) ask ) == 1 )
+  ask = i18n("Do you really want to remove job No %1?").arg(job);
+  if( KMessageBox::questionYesNo(this, ask) == KMessageBox::Yes)
     {
       QString progname;
       progname = spooler->removeCommand( cb_printer->text( cb_printer->currentItem() ), word );
-      system( (const char *) progname);
+      system( progname );
       update();
     }
 }
@@ -415,23 +332,23 @@ void Klpq::makeTop()
 {
   if( !isEnabled() )
     return;
-  int i = lb_list->currentItem();
-  if ( i < 0) return;
-  int job = lb_list->jobId(i);
+  int job = ((MyLVI *)lb_list->selectedItem())->jobId();
   QString word;
   word.setNum(job);
-  QString ask;
-  ask.sprintf( klocale->translate("Do you really want to move job No\n%d\non top of queue"), job);
-  if( KMsgBox::yesNo( this, "Klpq", (const char *) ask) == 1 )
+
+  QString msg = i18n(""
+    "Do you really want to move job No %1\non top of queue?").arg(job);
+  if( KMessageBox::questionYesNo( this, msg ) == KMessageBox::Yes )
+  {
+    lpc->clearArguments();
+    spooler->makeTopCommand( lpc, cb_printer->text(cb_printer->currentItem()),
+			     word );
+    if( lpc->start( KProcess::NotifyOnExit, KProcess::Stdout ) )
     {
-      lpc->clearArguments();
-      spooler->makeTopCommand( lpc, cb_printer->text( cb_printer->currentItem() ), word );
-      if( lpc->start( KProcess::NotifyOnExit, KProcess::Stdout ) )
-	{
-	  lpc_com = MakeTop;
-	  disable();
-	}
+      lpc_com = MakeTop;
+      disable();
     }
+  }
 }
 
 void Klpq::setAuto()
@@ -439,8 +356,11 @@ void Klpq::setAuto()
   if( update_delay == 0 )
     {
       b_auto->setOn( FALSE );
+      b_auto->setEnabled(FALSE);
       return;
-    }
+    } else
+      b_auto->setEnabled(TRUE);
+
   if( b_auto->isOn() )
     {
       if( cb_printer->count() )
@@ -449,10 +369,6 @@ void Klpq::setAuto()
     }
 }
 
-void Klpq::startHelp()
-{
-  KApplication::getKApplication()->invokeHTMLHelp( "", "" );
-}
 
 void Klpq::prevPrinter()
 {
@@ -478,29 +394,29 @@ void Klpq::nextPrinter()
 
 void Klpq::configureAuto()
 {
-  if( conf_auto->exec() )
-    update_delay = conf_auto->getFreq();
-  else
-    conf_auto->setFreq(update_delay);
+  if( conf_auto->exec() ) {
+    update_delay = conf_auto->getFrequency();
+    setAuto();
+  } else
+    conf_auto->setFrequency(update_delay);
 }
 
 void Klpq::configureSpooler()
 {
-  QString temp;
-  KConfig *config = KApplication::getKApplication()->getConfig();
-  config->setGroup("klpq");
-  conf_spooler->initConfig( config->readEntry("Spooler", "BSD") );
+  KConfig &config = *kapp->config();
+  config.setGroup("klpq");
+  conf_spooler->initConfig( config.readEntry("Spooler", "BSD") );
   if( conf_spooler->exec() )
-    {
-      temp = conf_spooler->saveConfig();
-      delete spooler;
-      if( temp == "BSD" )
-	spooler = new SpoolerBsd;
-      else if( temp == "PPR" )
-	spooler = new SpoolerPpr;
-      else if ( temp == "LPRNG" )
-	spooler = new SpoolerLprng;
-    }
+  {
+    QString spoolerName = conf_spooler->saveConfig();
+    delete spooler;
+    if( spoolerName == "BSD" )
+      spooler = new SpoolerBsd;
+    else if( spoolerName == "PPR" )
+      spooler = new SpoolerPpr;
+    else if ( spoolerName == "LPRNG" )
+      spooler = new SpoolerLprng;
+  }
 }
 
 void Klpq::enable()
@@ -525,12 +441,18 @@ void Klpq::updateList()
   lb_list->clear();
   lb_status->clear();
   spooler->parseUpdate( lb_list, lb_status, lpq_in_buffer );
-  lb_status->setUpdatesEnabled(TRUE);
   lb_list->setUpdatesEnabled(TRUE);
-  if( lb_list->count() )
-    lb_list->setCurrentItem( 0 );
-  lb_list->repaint(FALSE); 
-  lb_status->repaint(TRUE); 
+  lb_status->setUpdatesEnabled(TRUE);
+
+  int jobs = lb_list->childCount();
+  if( jobs != 0 )
+    lb_list->setSelected( lb_list->firstChild(), TRUE );
+
+  b_remove->setEnabled( jobs != 0 );
+  b_make_top->setEnabled( jobs != 0 );
+
+  lb_list->repaint(FALSE);
+  lb_status->repaint(TRUE);
   // --- exec lpc
   if( lpc_com == NotRunning )
     {
@@ -569,15 +491,15 @@ void Klpq::recvLpc( KProcess *, char *buffer, int len )
     break;
   case Queuing:
     if( spooler->parseQueuing( buffer, len ) < 0 )
-      QMessageBox::information( this, klocale->translate("Permission denied"),
-				klocale->translate("This is a privileged command\n"
-"and you do not have permission to execute it.") );
+      KMessageBox::error( this, i18n("This is a privileged command\n"
+				     "and you do not have permission to execute it."),
+				i18n("Permission denied"));
     break;
   case Printing:
     if( spooler->parsePrinting( buffer, len) < 0 )
-      QMessageBox::information( this, klocale->translate("Permission denied"),
-				klocale->translate("This is a privileged command\n"
-"and you do not have permission to execute it.") );
+      KMessageBox::error( this, i18n("This is a privileged command\n"
+				     "and you do not have permission to execute it."),
+				i18n("Permission denied"));
     break;
   case MakeTop:
     while( (c = *(buffer+j)) && j < len )
@@ -590,9 +512,10 @@ void Klpq::recvLpc( KProcess *, char *buffer, int len )
 	  {
 	    if(temp.contains("Privileged") || temp.contains("permission") )
 	      {
-		KMsgBox::message( this, klocale->translate("Permission denied"),
-				  klocale->translate("This is a privileged command\n"
-"and you do not have permission to execute it.") );
+		KMessageBox::error( this,
+				      i18n("This is a privileged command\n"
+					   "and you do not have permission to execute it."),
+				      i18n("Permission denied"));
 		return;
 	      }
 	    temp = "";
@@ -615,12 +538,23 @@ void Klpq::exitedLpc(KProcess *)
   update();
 }
 
-void Klpq::urlDroped(KDNDDropZone *zone)
+
+void Klpq::dragEnterEvent(QDragEnterEvent* event)
+{
+  event->accept(QUrlDrag::canDecode(event));
+}
+
+
+void Klpq::dropEvent(QDropEvent* event)
 {
-  if( zone->getDataType() != DndURL )
-    return;
   QString name;
-  QStrListIterator it(zone->getURLList());
+  QStrList urls;
+
+  if(!QUrlDrag::decode(event, urls))
+    return;
+
+  QStrListIterator it(urls);
+
   for( ; it.current(); ++it )
     {
       name = (QString) it.current();
@@ -638,22 +572,22 @@ void Klpq::urlDroped(KDNDDropZone *zone)
 	}
     }
   update();
-  if( !kfm && remote_files.count() )
+  if( remote_files.count() )
     {
       // start download of files
       QString pid, current_file;
       pid.setNum(::getpid());
       current_file = "file:/tmp/klpq_download.";
       current_file += pid;
-      kfm = new KFM;
-      connect( kfm, SIGNAL(finished()), this, SLOT(slotKFMJobDone()) );
       QString temp = remote_files.first();
       temp = temp.remove(0, temp.find(':')+1);
-      kfm->copy( temp, current_file );
+      KIO::Job* iojob = KIO::copy(temp, current_file);
+//      iojob->setGUImode ( KIOJob::NONE );
+      connect( iojob, SIGNAL( result(KIO::Job *) ), this, SLOT( slotIOJobFinished( KIO::Job* ) ) );
     }
 }
 
-void Klpq::slotKFMJobDone()
+void Klpq::slotIOJobFinished( KIO::Job* )
 {
   QString pid, current_file;
   pid.setNum(::getpid());
@@ -678,12 +612,11 @@ void Klpq::slotKFMJobDone()
     {
       QString temp = remote_files.first();
       temp = temp.remove(0, temp.find(':')+1);
-      kfm->copy( temp, "file:" + current_file );
+      KIO::Job* iojob = KIO::copy(temp, "file:" + current_file);
+      connect( iojob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotIOJobFinished( KIO::Job* ) ) );
     }
   else
     {
-      delete kfm;
-      kfm = 0;
       if( !isVisibleToTLW() )
 	QApplication::exit();
       QTimer::singleShot( 2000, this, SLOT(update()) );
@@ -697,11 +630,10 @@ void Klpq::printRemote( QStrList file_list )
   pid.setNum(::getpid());
   current_file = "file:/tmp/klpq_download.";
   current_file += pid;
-  kfm = new KFM;
-  connect( kfm, SIGNAL(finished()), this, SLOT(slotKFMJobDone()) );
   QString temp = remote_files.first();
   temp = temp.remove(0, temp.find(':')+1);
-  kfm->copy( temp, current_file );  
+  KIO::Job * iojob = KIO::copy(temp, current_file);
+  connect( iojob, SIGNAL( result( KIO::Job* ) ), this, SLOT( slotIOJobFinished( KIO::Job* ) ) );
 }
 
 void Klpq::popupMenu()
