@@ -24,45 +24,20 @@
 #ifndef queueview_included
 #define queueview_included
 
-#include "kheader.h"
-#include "krowtable.h"
+#include <qlistview.h>
 
-class MyRow : public KRow
+class MyLVI : public QListViewItem
 {
 public:
-  MyRow(QString ra, QString ow, int jo, QString fi, QString si);
-  virtual ~MyRow() {}
+  MyLVI(QListView *parent, const QString& ra, const QString& ow, int jo, 
+	const QString& fi, const QString& si);
+  virtual ~MyLVI() {}
 
   int jobId() { return job; }
 protected:
-  void paint( QPainter *painter, int col, int width );
-
-  QString rank;
-  QString owner;
   int     job;
-  QString files;
-  QString size;
 };
 
-class MyRowTable : public KRowTable
-{
-  Q_OBJECT
-public:
-  MyRowTable( QWidget *parent = NULL, const char *name = NULL );
-  ~MyRowTable() {}
-
-  void insertItem( QString row );
-  void clear();
-  int  currentItem() { return currentRow(); }
-  void setCurrentItem(int row);
-  int  jobId(int row);
-  int  count() { return numRows(); }
-
-protected:
-  int current;
-};
-
-
 #endif /* queueview_included */
 
 
