@@ -1,7 +1,7 @@
 
 /*
 
- $Id: alarm.h,v 1.2 1997/12/12 16:43:33 denis Exp $
+ $Id: alarm.h,v 1.4 1999/12/30 14:05:07 espen Exp $
 
  KPostit -- postit Notes for the KDE project
 
@@ -29,55 +29,34 @@
 #ifndef _ALARM_DLG_H_
 #define _ALARM_DLG_H_
 
-#include <qgrpbox.h> 
-#include <qchkbox.h>
-#include <qdialog.h>
-#include <qlined.h>
-#include <qpushbt.h>
-#include <qpainter.h>
-#include <qlabel.h>
-#include <qframe.h>
-#include <qdatetm.h> 
+#include <qdatetime.h> 
+#include <kdialogbase.h>
 
-#include <kcolordlg.h>
-#include "knotes.h"
-#include <bwdatetime.h>
+class KPostit;
+class BWDateTime;
 
-#include <spin.h>
-
-class AlarmDlg : public QDialog
+class AlarmDialog : public KDialogBase
 {
-    Q_OBJECT
+  Q_OBJECT
 
-public:
+  public:
+    AlarmDialog( KPostit *parent, const char *name=0, bool modal=true );
+    ~AlarmDialog( void );
 
-    AlarmDlg ( KPostit *parent = 0, const char *name=0);
+    QDateTime getDateTime( void );
 
-    QDateTime getDateTime();
+  protected slots:
+    virtual void slotUser1( void );
 
-protected:
+  private:
+    bool checkDateTime( void );
 
-    void focusInEvent( QFocusEvent *);
-    void resizeEvent ( QResizeEvent *);
-
-private:
-
-    QString pname;
-    QDateTime mydatetime;
-    QDateTime qdt;
-    QPushButton *ok, *cancel;
-    QGroupBox 	*frame1;
-    KPostit *postit;
-    BWDateTime *spins;
-    bool alarm_is_on;
-
-public slots:
-     
-    void cancel_slot();
-    void ok_slot();
-
-private:
-    bool checkDateTime();
+  private:
+    KPostit    *mPostit;
+    BWDateTime *mSpins;
+    QDateTime  mDateTime;
+    bool       mAlarmActive;
 };
 
 #endif
+
