@@ -1,6 +1,6 @@
 /*
 
- $Id: timer.h,v 1.2 1998/05/29 03:42:14 wuebben Exp $
+ $Id: timer.h,v 1.4 1999/08/03 12:56:04 pfeiffer Exp $
 
  KNotes -- Notes for the KDE project
 
@@ -27,7 +27,7 @@
 #ifndef __KPOSTIT_TIMER__
 #define __KPOSTIT_TIMER__
 
-#include <qapp.h>
+#include <qapplication.h>
 
 class MyTimer : public QObject{
 
@@ -38,6 +38,7 @@ public:
 
 protected:
   virtual void timerEvent( QTimerEvent * );
+  void 	       playSound( QString );
 
 public:
   void start();
