@@ -5,8 +5,7 @@
 #include <qpixmap.h>
 #include <stdio.h>
 #include <kprocess.h>
-#include <qpopmenu.h>
-#include <kquickhelp.h>
+#include <qpopupmenu.h>
 #include <ktmainwindow.h>
 
 #define ICONWIDTH 24
@@ -34,7 +33,6 @@ private:
   int idle;
   QPopupMenu *menu, *options;
   KConfig *conf;  
-  KQuickHelpWindow *qh;
   float av1, av2, av3;
 
   void clearHistory();
