@@ -6,35 +6,38 @@
 #ifndef FIELDSEL_H
 #define FIELDSEL_H
 
-#include <qdialog.h>
-#include <qbitarry.h>
-#include <qchkbox.h>
-#include "proc.h"
+#include <qbitarray.h>
+#include <kdialogbase.h>
 
-class FieldSelect : public QDialog {
-    Q_OBJECT
-public:
-    FieldSelect(Procview *pv, Proc *proc);
+class QCheckBox;
+class Procview;
 
+class FieldSelect : public KDialogBase 
+{
+  Q_OBJECT
+
+  public:
+    FieldSelect(Procview *pv, Proc *proc, QWidget *parent=0, 
+		const char *name=0, bool modal=true );
     void update_boxes();
 
-public slots:
+  public slots:
     void field_toggled(bool);
-    void closed();
 
-signals:
+  protected:
+    void set_disp_fields( void );
+
+  signals:
     void added_field(int);
     void removed_field(int);
 
-protected:
+  protected:
     QCheckBox **buts;
     int nbuttons;
     QBitArray disp_fields;
     bool updating;
     Procview *procview;
-
-    void set_disp_fields();
-    void closeEvent(QCloseEvent *);
 };
 
 #endif	// FIELDSEL_H
+
